﻿using System;
using System.Linq;
using Telerik.Windows.Controls.Diagrams.Extensions.ViewModels;
using Telerik.Windows.Diagrams.Core;

namespace Diagram_MVVMConnectors.GraphSource
{
	public class GraphSource : SerializableGraphSourceBase<NodeViewModelBase, Link>
	{


		public override void SerializeNode(NodeViewModelBase node, SerializationInfo info)
		{
			base.SerializeNode(node, info);
			if (node.Content != null)
				info["Content"] = node.Content.ToString();
			else
				info["Content"] = string.Empty;


			// If you create your connectors in the viewModel you don't need to serialize them.
			info["Connectors"] = null;
		}

		public override NodeViewModelBase DeserializeNode(IShape shape, Telerik.Windows.Diagrams.Core.SerializationInfo info)
		{
			NodeViewModelBase node = null;
			if (shape is IContainerShape)
			{
				node = new ContainerNode();
			}
			else
			{
				node = new Node();
			}
			if (info["Content"] != null)
				node.Content = info["Content"].ToString();
			if (info[this.NodeUniqueIdKey] != null)
			{
				var nodeUniquekey = info[this.NodeUniqueIdKey].ToString();
				this.CachedNodes[nodeUniquekey] = node;
			}

			return node;
		}

		public override void SerializeLink(Link link, SerializationInfo info)
		{
			this.ClearCache();
			base.SerializeLink(link, info);
		}

		public override string GetNodeUniqueId(NodeViewModelBase node)
		{
			if (node != null)
				return node.GetHashCode().ToString();

			return string.Empty;
		}

		public override object CreateNode(IShape shape)
		{
			var newItem = base.CreateNode(shape);
			if (shape.Content != null)
				(newItem as NodeViewModelBase).Content = shape.Content;

			return newItem;
		}
	}
}
